pub struct RecoveryStorage;Expand description
Persistent storage for recovery guardians, config, and active requests.
Implementations
Sourceimpl RecoveryStorage
impl RecoveryStorage
Sourcepub fn store_guardians(env: &Env, account: &Address, guardians: &Vec<Guardian>)
pub fn store_guardians(env: &Env, account: &Address, guardians: &Vec<Guardian>)
Store the full guardians list for an account (overwrites).
Sourcepub fn load_guardians(env: &Env, account: &Address) -> Vec<Guardian>
pub fn load_guardians(env: &Env, account: &Address) -> Vec<Guardian>
Load the guardians list. Returns empty vec if none stored.
Sourcepub fn store_config(env: &Env, account: &Address, config: &RecoveryConfig)
pub fn store_config(env: &Env, account: &Address, config: &RecoveryConfig)
Store recovery configuration for an account.
Sourcepub fn load_config(env: &Env, account: &Address) -> Option<RecoveryConfig>
pub fn load_config(env: &Env, account: &Address) -> Option<RecoveryConfig>
Load recovery configuration. Returns None if not set.
Sourcepub fn store_request(env: &Env, account: &Address, request: &RecoveryRequest)
pub fn store_request(env: &Env, account: &Address, request: &RecoveryRequest)
Store an active recovery request.
Sourcepub fn load_request(env: &Env, account: &Address) -> Option<RecoveryRequest>
pub fn load_request(env: &Env, account: &Address) -> Option<RecoveryRequest>
Load the active recovery request. Returns None if none active.
Sourcepub fn remove_request(env: &Env, account: &Address)
pub fn remove_request(env: &Env, account: &Address)
Remove the active recovery request.