pub trait AppSystem: SimpleSystem { }Expand description
Marker trait for systems that participate in the Soroban-first app runtime.
This is the preferred system model for GameApp and SimpleScheduler.
pub trait AppSystem: SimpleSystem { }Marker trait for systems that participate in the Soroban-first app runtime.
This is the preferred system model for GameApp and SimpleScheduler.