GameApp

Struct GameApp 

pub struct GameApp { /* private fields */ }
Soroban-first application builder and runtime.

GameApp is the recommended entrypoint for new Cougr projects: it owns the SimpleWorld, the validated SimpleScheduler, and hook registration in one place.

Example

let env = Env::default();
let mut app = GameApp::new(&env);
app.add_plugin(PhysicsPlugin);
app.add_plugin(ScoringPlugin);
app.run(&env).unwrap();
let world = app.into_world();
assert_eq!(world.version(), 0);

Implementations

Source

impl GameApp

pub fn new(env: &Env) -> Self

pub fn with_world(world: SimpleWorld) -> Self

pub fn add_plugin<P: Plugin>(&mut self, plugin: P) -> &mut Self

pub fn add_plugins<G: PluginGroup>(&mut self, group: G) -> &mut Self

pub fn add_system<F>(&mut self, name: &'static str, system: F) -> &mut Self
where F: FnMut(&mut SimpleWorld, &Env) + 'static,

Add a world/env system to the default Update stage.

pub fn add_system_with_config<F>( &mut self, name: &'static str, system: F, config: SystemConfig, ) -> &mut Self
where F: FnMut(&mut SimpleWorld, &Env) + 'static,

Add a world/env system with explicit scheduling rules.

pub fn add_system_in_stage<F>( &mut self, stage: ScheduleStage, name: &'static str, system: F, ) -> &mut Self
where F: FnMut(&mut SimpleWorld, &Env) + 'static,

Add a world/env system directly to a specific stage.

pub fn add_context_system<F>( &mut self, name: &'static str, system: F, ) -> &mut Self
where F: for<'w, 'e, 'c> FnMut(&mut SystemContext<'w, 'e, 'c>) + 'static,

Add a context-aware system to the default Update stage.

pub fn add_context_system_with_config<F>( &mut self, name: &'static str, system: F, config: SystemConfig, ) -> &mut Self
where F: for<'w, 'e, 'c> FnMut(&mut SystemContext<'w, 'e, 'c>) + 'static,

Add a context-aware system with explicit scheduling rules.

pub fn add_context_system_in_stage<F>( &mut self, stage: ScheduleStage, name: &'static str, system: F, ) -> &mut Self
where F: for<'w, 'e, 'c> FnMut(&mut SystemContext<'w, 'e, 'c>) + 'static,

Add a context-aware system directly to a specific stage.

pub fn add_simple_system<S>( &mut self, name: &'static str, system: S, ) -> &mut Self
where S: AppSystem + 'static,

Add any pre-built runtime system to the default Update stage.

pub fn add_simple_system_with_config<S>( &mut self, name: &'static str, system: S, config: SystemConfig, ) -> &mut Self
where S: AppSystem + 'static,

Add any pre-built runtime system with explicit scheduling rules.

pub fn add_simple_system_in_stage<S>( &mut self, stage: ScheduleStage, name: &'static str, system: S, ) -> &mut Self
where S: AppSystem + 'static,

Add any pre-built runtime system directly to a specific stage.

pub fn add_systems<G>(&mut self, systems: G) -> &mut Self
where G: SystemGroup,

Add one or more runtime systems using declarative specs.

pub fn add_systems_in_stage<G>( &mut self, stage: ScheduleStage, systems: G, ) -> &mut Self
where G: SystemGroup,

Add one or more runtime systems while forcing them into a stage.

pub fn add_startup_system<F>( &mut self, name: &'static str, system: F, ) -> &mut Self
where F: FnMut(&mut SimpleWorld, &Env) + 'static,

Convenience wrapper to register a startup-only system.

pub fn add_hook_on_add( &mut self, component_type: Symbol, hook: fn(entity_id: EntityId, component_type: &Symbol, data: &Bytes), ) -> &mut Self

pub fn add_hook_on_remove( &mut self, component_type: Symbol, hook: fn(entity_id: EntityId, component_type: &Symbol), ) -> &mut Self

pub fn insert_resource<R: ResourceTrait>( &mut self, env: &Env, resource: &R, ) -> &mut Self

pub fn get_resource<R: ResourceTrait>(&self, env: &Env) -> Option<R>

pub fn remove_resource<R: ResourceTrait>(&mut self) -> Option<Resource>

pub fn world(&self) -> &SimpleWorld

pub fn world_mut(&mut self) -> &mut SimpleWorld

pub fn scheduler(&self) -> &SimpleScheduler

pub fn hooks(&self) -> &HookRegistry

pub fn resources(&self) -> &Vec<Resource>

pub fn run_startup(&mut self, env: &Env) -> Result<(), ScheduleError>

pub fn run(&mut self, env: &Env) -> Result<(), ScheduleError>

Run one gameplay tick.

pub fn run_stage( &mut self, stage: ScheduleStage, env: &Env, ) -> Result<(), ScheduleError>

pub fn configure_system( &mut self, name: &str, config: SystemConfig, ) -> Result<&mut Self, ScheduleError>

pub fn into_world(self) -> SimpleWorld

pub fn plugin_count(&self) -> usize

pub fn has_plugin(&self, name: &str) -> bool

pub fn system_count(&self) -> usize