pub struct HookRegistry { /* private fields */ }Expand description
Registry of component lifecycle hooks.
Hooks are runtime-only (not persisted to on-chain storage) and must be re-registered each contract invocation. They allow reactive patterns such as updating indexes or cleaning up related state.
Example
use cougr_core::runtime::HookRegistry;
use soroban_sdk::{symbol_short, Bytes, Symbol};
fn on_add(_entity_id: u32, _ctype: &Symbol, _data: &Bytes) {}
let mut hooks = HookRegistry::new();
hooks.on_add(symbol_short!("pos"), on_add);
assert_eq!(hooks.add_hook_count(), 1);Implementations
Sourceimpl HookRegistry
impl HookRegistry
Sourcepub fn on_add(
&mut self,
component_type: Symbol,
hook: fn(entity_id: EntityId, component_type: &Symbol, data: &Bytes),
)
pub fn on_add( &mut self, component_type: Symbol, hook: fn(entity_id: EntityId, component_type: &Symbol, data: &Bytes), )
Register a hook that fires when a component of the given type is added.
Sourcepub fn on_remove(
&mut self,
component_type: Symbol,
hook: fn(entity_id: EntityId, component_type: &Symbol),
)
pub fn on_remove( &mut self, component_type: Symbol, hook: fn(entity_id: EntityId, component_type: &Symbol), )
Register a hook that fires when a component of the given type is removed.
Sourcepub fn fire_on_add(
&self,
entity_id: EntityId,
component_type: &Symbol,
data: &Bytes,
)
pub fn fire_on_add( &self, entity_id: EntityId, component_type: &Symbol, data: &Bytes, )
Fire all registered on_add hooks for the given component type.
Sourcepub fn fire_on_remove(&self, entity_id: EntityId, component_type: &Symbol)
pub fn fire_on_remove(&self, entity_id: EntityId, component_type: &Symbol)
Fire all registered on_remove hooks for the given component type.
Sourcepub fn add_hook_count(&self) -> usize
pub fn add_hook_count(&self) -> usize
Returns the number of registered add hooks.
Sourcepub fn remove_hook_count(&self) -> usize
pub fn remove_hook_count(&self) -> usize
Returns the number of registered remove hooks.