pub struct ObserverRegistry { /* private fields */ }Expand description
Registry of component observers that fire on component events.
Observers are runtime-only (not persisted) and must be re-registered each contract invocation. They provide reactive patterns where systems trigger immediately on component changes rather than polling.
Example
use cougr_core::runtime::{ComponentEvent, ObserverRegistry};
use cougr_core::SimpleWorld;
use soroban_sdk::{symbol_short, Env};
fn on_position_added(_event: &ComponentEvent, _world: &SimpleWorld, _env: &Env) {}
let mut registry = ObserverRegistry::new();
registry.on_add(symbol_short!("pos"), on_position_added);
assert_eq!(registry.observer_count(), 1);Implementations
Sourceimpl ObserverRegistry
impl ObserverRegistry
Sourcepub fn on_add(
&mut self,
component_type: Symbol,
observer: fn(event: &ComponentEvent, world: &SimpleWorld, env: &Env),
)
pub fn on_add( &mut self, component_type: Symbol, observer: fn(event: &ComponentEvent, world: &SimpleWorld, env: &Env), )
Register an observer that fires when a component of the given type is added.
Sourcepub fn on_remove(
&mut self,
component_type: Symbol,
observer: fn(event: &ComponentEvent, world: &SimpleWorld, env: &Env),
)
pub fn on_remove( &mut self, component_type: Symbol, observer: fn(event: &ComponentEvent, world: &SimpleWorld, env: &Env), )
Register an observer that fires when a component of the given type is removed.
Sourcepub fn fire(&self, event: &ComponentEvent, world: &SimpleWorld, env: &Env)
pub fn fire(&self, event: &ComponentEvent, world: &SimpleWorld, env: &Env)
Fire all matching observers for the given event.
Sourcepub fn observer_count(&self) -> usize
pub fn observer_count(&self) -> usize
Returns the total number of registered observers.