pub struct CommandQueue { /* private fields */ }Expand description
A deferred command queue for safe structural changes during system iteration.
Instead of mutating the world directly while iterating entities, systems can queue commands and apply them after iteration completes.
Example
use cougr_core::commands::CommandQueue;
use cougr_core::simple_world::SimpleWorld;
use soroban_sdk::{symbol_short, Bytes, Env};
let env = Env::default();
let mut world = SimpleWorld::new(&env);
let mut commands = CommandQueue::new();
commands.spawn();
let spawned = commands.apply(&mut world);
commands = CommandQueue::new();
commands.add_component(spawned[0], symbol_short!("bullet"), Bytes::new(&env));
commands.apply(&mut world);
assert!(world.has_component(spawned[0], &symbol_short!("bullet")));Implementations
Sourceimpl CommandQueue
impl CommandQueue
Sourcepub fn spawn(&mut self)
pub fn spawn(&mut self)
Queue a new entity spawn. The entity ID is assigned when apply() is called.
Sourcepub fn add_component(
&mut self,
entity_id: EntityId,
component_type: Symbol,
data: Bytes,
)
pub fn add_component( &mut self, entity_id: EntityId, component_type: Symbol, data: Bytes, )
Queue adding a component (Table storage) to an entity.
Sourcepub fn add_sparse_component(
&mut self,
entity_id: EntityId,
component_type: Symbol,
data: Bytes,
)
pub fn add_sparse_component( &mut self, entity_id: EntityId, component_type: Symbol, data: Bytes, )
Queue adding a component with Sparse storage to an entity.
Sourcepub fn remove_component(&mut self, entity_id: EntityId, component_type: Symbol)
pub fn remove_component(&mut self, entity_id: EntityId, component_type: Symbol)
Queue removing a component from an entity.