pub struct TrackedWorld { /* private fields */ }Expand description
A wrapper around SimpleWorld that automatically records component changes.
Similar to HookedWorld, but instead of firing callbacks, it records changes
in a ChangeTracker for later querying by systems.
Example
use cougr_core::{SimpleWorld, runtime::TrackedWorld};
use soroban_sdk::{symbol_short, Bytes, Env};
let env = Env::default();
let world = SimpleWorld::new(&env);
let mut tracked = TrackedWorld::new(world);
let e1 = tracked.spawn_entity();
tracked.add_component(e1, symbol_short!("pos"), Bytes::new(&env));
assert!(tracked.tracker().was_added(e1, &symbol_short!("pos")));Implementations
Sourceimpl TrackedWorld
impl TrackedWorld
Sourcepub fn new(world: SimpleWorld) -> Self
pub fn new(world: SimpleWorld) -> Self
Wrap a SimpleWorld with a new change tracker.
Sourcepub fn world(&self) -> &SimpleWorld
pub fn world(&self) -> &SimpleWorld
Access the underlying SimpleWorld.
Sourcepub fn world_mut(&mut self) -> &mut SimpleWorld
pub fn world_mut(&mut self) -> &mut SimpleWorld
Mutably access the underlying SimpleWorld.
Sourcepub fn tracker(&self) -> &ChangeTracker
pub fn tracker(&self) -> &ChangeTracker
Access the change tracker.
Sourcepub fn tracker_mut(&mut self) -> &mut ChangeTracker
pub fn tracker_mut(&mut self) -> &mut ChangeTracker
Mutably access the change tracker (e.g. to clear it).
Sourcepub fn into_inner(self) -> SimpleWorld
pub fn into_inner(self) -> SimpleWorld
Consume the wrapper and return the inner SimpleWorld.
Sourcepub fn spawn_entity(&mut self) -> EntityId
pub fn spawn_entity(&mut self) -> EntityId
Spawn a new entity (delegates to SimpleWorld).
Sourcepub fn add_component(
&mut self,
entity_id: EntityId,
component_type: Symbol,
data: Bytes,
)
pub fn add_component( &mut self, entity_id: EntityId, component_type: Symbol, data: Bytes, )
Add a component, recording the change.
Sourcepub fn add_component_with_storage(
&mut self,
entity_id: EntityId,
component_type: Symbol,
data: Bytes,
storage: ComponentStorage,
)
pub fn add_component_with_storage( &mut self, entity_id: EntityId, component_type: Symbol, data: Bytes, storage: ComponentStorage, )
Add a component with explicit storage kind, recording the change.
Sourcepub fn remove_component(
&mut self,
entity_id: EntityId,
component_type: &Symbol,
) -> bool
pub fn remove_component( &mut self, entity_id: EntityId, component_type: &Symbol, ) -> bool
Remove a component, recording the change.
Sourcepub fn get_component(
&self,
entity_id: EntityId,
component_type: &Symbol,
) -> Option<Bytes>
pub fn get_component( &self, entity_id: EntityId, component_type: &Symbol, ) -> Option<Bytes>
Get a component (delegates to SimpleWorld).
Sourcepub fn has_component(
&self,
entity_id: EntityId,
component_type: &Symbol,
) -> bool
pub fn has_component( &self, entity_id: EntityId, component_type: &Symbol, ) -> bool
Check if an entity has a component (delegates to SimpleWorld).
Sourcepub fn despawn_entity(&mut self, entity_id: EntityId)
pub fn despawn_entity(&mut self, entity_id: EntityId)
Despawn an entity, recording removals for each component.